@@ -9,6 +9,7 @@
 # *** WARNING: generated file
 import os
 import json
+import types
 import base64
 import inspect
 import datetime
@@ -130,7 +131,7 @@ def to_intermediate(obj: Any) -> Any:
     if isinstance(obj, list):
         return [*map(to_intermediate, obj)]
 
-    if callable(obj):
+    if isinstance(obj, types.FunctionType):
         return base64.b64encode(inspect.getsource(obj).encode("utf-8")).decode("utf-8")
 
     return obj
