@@ -89,11 +89,23 @@ class PythonFilter(_BaseFilter):
 
     Attributes:
         - func -- Custom python filter (required)
+        - params -- Custom python filter (optional, default: None)
 
     """
 
     # required
-    func: typing.Callable[[typing.Any], bool]
+    func: typing.Callable[
+        [
+            typing.Any,
+            typing.Optional[typing.Dict[str, typing.Union[str, int, float, bool]]],
+        ],
+        bool,
+    ]
+
+    # optional
+    params: typing.Optional[
+        typing.Dict[str, typing.Union[str, int, float, bool]]
+    ] = None
 
     # internal private methods
     def _typename(self) -> str:
@@ -103,7 +115,7 @@ class PythonFilter(_BaseFilter):
         return ""
 
     def _fields(self) -> typing.List[str]:
-        return ["func"]
+        return ["func", "params"]
 
 
 @dataclasses.dataclass(frozen=True)
